==> google-cloud-dialogflow-cx-0.1.0.tar.gz: google-cloud-dialogflow-cx-0.1.0/google/cloud/dialogflowcx_v3beta1/services/pages/pagers.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from typing import Any, AsyncIterable, Awaitable, Callable, Iterable, Sequence, Tuple

from google.cloud.dialogflowcx_v3beta1.types import page


class ListPagesPager:
    """A pager for iterating through ``list_pages`` requests.

    This class thinly wraps an initial
    :class:`~.page.ListPagesResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``pages`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListPages`` requests and continue to iterate
    through the ``pages`` field on the
    corresponding responses.

    All the usual :class:`~.page.ListPagesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., page.ListPagesResponse],
        request: page.ListPagesRequest,
        response: page.ListPagesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (:class:`~.page.ListPagesRequest`):
                The initial request object.
            response (:class:`~.page.ListPagesResponse`):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = page.ListPagesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterable[page.ListPagesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterable[page.Page]:
        for page in self.pages:
            yield from page.pages

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListPagesAsyncPager:
    """A pager for iterating through ``list_pages`` requests.

    This class thinly wraps an initial
    :class:`~.page.ListPagesResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``pages`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListPages`` requests and continue to iterate
    through the ``pages`` field on the
    corresponding responses.

    All the usual :class:`~.page.ListPagesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[page.ListPagesResponse]],
        request: page.ListPagesRequest,
        response: page.ListPagesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (:class:`~.page.ListPagesRequest`):
                The initial request object.
            response (:class:`~.page.ListPagesResponse`):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = page.ListPagesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterable[page.ListPagesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterable[page.Page]:
        async def async_generator():
            async for page in self.pages:
                for response in page.pages:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)

==> google-cloud-dialogflow-cx-1.26.0.tar.gz: google-cloud-dialogflow-cx-1.26.0/google/cloud/dialogflowcx_v3beta1/services/pages/pagers.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import (
    Any,
    AsyncIterator,
    Awaitable,
    Callable,
    Sequence,
    Tuple,
    Optional,
    Iterator,
)

from google.cloud.dialogflowcx_v3beta1.types import page


class ListPagesPager:
    """A pager for iterating through ``list_pages`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.dialogflowcx_v3beta1.types.ListPagesResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``pages`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListPages`` requests and continue to iterate
    through the ``pages`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.dialogflowcx_v3beta1.types.ListPagesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., page.ListPagesResponse],
        request: page.ListPagesRequest,
        response: page.ListPagesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.dialogflowcx_v3beta1.types.ListPagesRequest):
                The initial request object.
            response (google.cloud.dialogflowcx_v3beta1.types.ListPagesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = page.ListPagesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[page.ListPagesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[page.Page]:
        for page in self.pages:
            yield from page.pages

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListPagesAsyncPager:
    """A pager for iterating through ``list_pages`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.dialogflowcx_v3beta1.types.ListPagesResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``pages`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListPages`` requests and continue to iterate
    through the ``pages`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.dialogflowcx_v3beta1.types.ListPagesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[page.ListPagesResponse]],
        request: page.ListPagesRequest,
        response: page.ListPagesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.dialogflowcx_v3beta1.types.ListPagesRequest):
                The initial request object.
            response (google.cloud.dialogflowcx_v3beta1.types.ListPagesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = page.ListPagesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[page.ListPagesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[page.Page]:
        async def async_generator():
            async for page in self.pages:
                for response in page.pages:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
